/**
 * Ein Objekt zur Aufnahme eines Schlssel-Werte-Paares, wobei der Schlssel
 * stets vom Typ String, der Wert jedoch vom Typ String oder int sein kann.
 *
 * @author  <a href="mailto:jochen@kupperschmidt.de">Jochen Kupperschmidt</a>
 * @version 05. November 2002
 */
class KeyValuePair
{
	String  key				= null;
	String  stringValue		= null;
	int     intValue		= 0;
	boolean isString		= false;
	boolean isInt			= false;

	/* Konstruktor, richtiger Typ vom Wert wird automatisch ermittelt */
	public KeyValuePair(String key, Object value) {
		this.key		= key;
		try {
			intValue	= (new Integer(value.toString())).intValue();
			isInt		= true;
		} catch (NumberFormatException e) {
			stringValue = value.toString();
			isString	= true;
		}
	}

	/* Abfragen, ob der Wert vom Typ String ist */
	public boolean isString() {
		return isString;
	}

	/* Abfragen, ob der Wert vom Typ int ist */
	public boolean isInt() {
		return isInt;
	}

	/* Datentyp abfragen */
	public String getType() {
		return (isInt ? "int" : "String");
	}

	/* Schluessel auslesen */
	public String getKey() {
		return key;
	}

	/* Wert auslesen */
	public Object getValue() {
		return (isInt ? (new Integer(intValue)).toString() : stringValue);
	}


	/* Neuen Schlssel setzen */
	public void setKey(String key) {
		this.key = key;
	}

	/* Neuen Wert setzen */
	public void setValue(Object obj) {
		try {
			intValue	= (new Integer(obj.toString())).intValue();
			stringValue	= null;
			isString	= false;
			isInt		= true;
		} catch (NumberFormatException e) {
			stringValue = obj.toString();
			intValue	= 0;
			isString	= true;
			isInt		= false;
		}
	}
}