import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JTextField;

/**
 * Ein Swing-Dialog zum Bearbeiten von Schlssel-Wert-Paaren.
 *
 * @author  <a href="mailto:jochen@kupperschmidt.de">Jochen Kupperschmidt</a>
 * @version 15. November 2002
 */
public class SwingUIDialog extends JDialog implements ActionListener {
    private static final boolean DEBUG        = true;

    private JTextField           keyField     = new JTextField();
    private JTextField           valueField   = new JTextField();
    private JButton              changeButton = new JButton("\u00c4ndern");
    private JButton              cancelButton = new JButton("Abbrechen");
    private KeyValuePair         pair;

    /* Einstiegspunkt zum Testen */
    public static void main(String[] args) {
        new SwingUIDialog(new JFrame(), new KeyValuePair("TestKey", "TestValue"));
    }

    /* Konstruktor */
    public SwingUIDialog(JFrame frame, KeyValuePair pair) {
        super(frame, "Bearbeiten", true);

        // bergebenen Schlssel und Wert einlesen
        this.pair = pair;
        keyField.setText(pair.getKey());
        valueField.setText((String) pair.getValue());

        // Erzeugen eines 2x2-Panels mit Labeln und Textfeldern
        JPanel fieldPanel = new JPanel();
        fieldPanel.setBorder(BorderFactory.createEmptyBorder(5, 5, 0, 5));
        fieldPanel.setLayout(new GridLayout(2, 2, 1, 1));
        fieldPanel.add(new JLabel(" Schl\u00fcssel:", JLabel.LEFT));
        fieldPanel.add(keyField);
        fieldPanel.add(new JLabel(" Wert:", JLabel.LEFT));
        fieldPanel.add(valueField);

        // Erzeugen eines Panels mit den beiden Buttons
        JPanel buttonPanel = new JPanel();
        buttonPanel.setLayout(new FlowLayout(FlowLayout.RIGHT));
        Dimension buttonSize = new Dimension(99, 26);
        changeButton.setPreferredSize(buttonSize);
        cancelButton.setPreferredSize(buttonSize);
        changeButton.setActionCommand("CHANGE");
        cancelButton.setActionCommand("CANCEL");
        changeButton.addActionListener(this);
        cancelButton.addActionListener(this);
        buttonPanel.add(changeButton);
        buttonPanel.add(cancelButton);

        // Hinzufgen der einzelnen Panels zur Content Pane
        JPanel contentPane = new JPanel();
        contentPane.setLayout(new BorderLayout());
        contentPane.add(fieldPanel, BorderLayout.CENTER);
        contentPane.add(buttonPanel, BorderLayout.SOUTH);

        setContentPane(contentPane);
        setResizable(false);
        setDefaultCloseOperation(JDialog.DISPOSE_ON_CLOSE);
        setSize(215, 120);
        setLocation(300, 300);
        setVisible(true);
    }

    /* Event-Handler */
    public void actionPerformed(ActionEvent ae) {
        String cmd = ae.getActionCommand();
        debug("ActionCommand: " + cmd);
        if (cmd.equals("CANCEL")) {
            // Dialog schliessen
            setVisible(false);
        } else if (cmd.equals("CHANGE")) {
            // nderungen bernehmen
            pair.setKey(keyField.getText().trim());
            pair.setValue(valueField.getText().trim());
            setVisible(false);
        }
    }

    /* Debug-Ausgabe */
    private void debug(String msg) {
        if (DEBUG) {
            System.out.println("DEBUG ::[ " + msg);
        }
    }
}